@@ -18,12 +18,13 @@ from ssht00ls.classes.smartcards import smartcards, SmartCard
 from ssht00ls.classes.aliases import aliases
 from ssht00ls.classes.ssh import ssh
 from ssht00ls.classes.ssync import ssync
+from ssht00ls.classes.smb import smb
 
 # import objects.
-from ssht00ls.classes.client import Client
+from ssht00ls.classes.client import clients, Client
 
-# version.
+# source path & version.
 import fil3s
-SOURCE_PATH = fil3s.gfp.base(__file__)
-try: version = int(fil3s.Files.load(SOURCE_PATH+".version.py").replace("\n","").replace(" ",""))
+source_path = fil3s.gfp.base(__file__)
+try: version = fil3s.Files.load(source_path+".version.py").replace("\n","").replace(" ","")
 except: version = None
\ No newline at end of file
