@@ -7,4 +7,4 @@ import syst3m
 from ssht00ls.classes.config import encryption
 
 # import classes.
-from ssht00ls.classes import utils, installation, sshd, sshfs, scp, agent, keys, connections, smartcards, aliases, ssh, ssync, client
+from ssht00ls.classes import utils, installation, sshd, sshfs, scp, agent, keys, connections, smartcards, aliases, ssh, ssync, client, smb
