@@ -8,7 +8,7 @@ from ssht00ls.classes.smartcards import smartcards
 from ssht00ls.classes.ssh import ssh
 
 # the ssh agent object class.
-class Agent(object):
+class Agent(syst3m.objects.Traceback):
 	def __init__(self,
 		# initialize as specific not global (optional).
 		# the path to the public key.
@@ -19,15 +19,14 @@ class Agent(object):
 		smartcard=False,
 	):
 
+		# defaults.
+		syst3m.objects.Traceback.__init__(self, traceback="ssht00ls.agent", raw_traceback="ssht00ls.classes.agent.Agent")
+
 		# specific variables.
 		self.specific = public_key != None or private_key != None
 		self.private_key = private_key
 		self.public_key = public_key
 		self.smartcard = smartcard
-
-		# set agent.
-		if INTERACTIVE:
-			ssh.utils.ssh_agent()
 		
 		#
 	def add(self, 
@@ -56,12 +55,12 @@ class Agent(object):
 		private_key = private_key.replace("//", "/")
 		response = r3sponse.check_parameters(empty_value=None, parameters={
 			"private_key":private_key
-		})
+		}, traceback=self.__traceback__(function="add"))
 		if not response["success"]: return response
 		if smartcard:
 			response = r3sponse.check_parameters(empty_value=None, parameters={
 				"pin":pin
-			})
+			}, traceback=self.__traceback__(function="add"))
 			if not response["success"]: return response
 		else:
 			if not Files.exists(private_key):
@@ -245,7 +244,7 @@ class Agent(object):
 		# params.
 		response = r3sponse.check_parameters({
 			"public_key":public_key
-		})
+		}, traceback=self.__traceback__(function="check"))
 		if not response["success"]: return response
 
 		# checks.
@@ -320,6 +319,7 @@ class Agent(object):
 
 # Initialized objects.
 agent = Agent()
+if not INTERACTIVE: ssh.utils.ssh_agent()
 
 """
 
