@@ -7,7 +7,7 @@ from ssht00ls.classes import utils
 from ssht00ls.classes.agent import agent
 
 # the aliases object class.
-class Aliases(object):
+class Aliases(syst3m.objects.Traceback):
 	def __init__(self,
 		# initialize as specific not global (optional).
 		# 	the alias.
@@ -28,8 +28,13 @@ class Aliases(object):
 		private_key=None,
 		# 	the smart card boolean.
 		smartcard=False,
+		# 	the log level.
+		log_level=syst3m.defaults.options.log_level,
 	):
 		
+		# defaults.
+		syst3m.objects.Traceback.__init__(self, traceback="ssht00ls.aliases", raw_traceback="ssht00ls.classes.aliaes.Aliases")
+
 		# specific variables.
 		self.specific = alias != None
 		self.alias = alias
@@ -41,22 +46,31 @@ class Aliases(object):
 		self.private_key = private_key
 		self.public_key = public_key
 		self.smartcard = smartcard
+		self.log_level = log_level
 
 		# sync non interactive.
-		self.sync(interactive=False)
+		#self.sync(interactive=False)
 
 		#
 	def list(self):
-		array = []
+		CONFIG.load()
+		array, dictionary = [], {}
 		for i in list(CONFIG["aliases"].keys()):
 			if len(i) >= len("example.com ") and i[:len("example.com ")] == "example.com ":
-				a=1
+				a=1 # skip
+			elif i in ["None", None]:
+				a=1 # skip
 			else:
 				array.append(i)
-		return array
+				dictionary[i] = dict(CONFIG["aliases"][i])
+		return r3sponse.success(f"Successfully listed {len(array)} aliases.", {
+			"aliases":array,
+			"array":array,
+			"dictionary":dictionary,
+		})
 	def iterate(self):
 		items = []
-		for key in self.list(): items.append([key, CONFIG["aliases"][key]])
+		for key in self.list()["aliases"]: items.append([key, CONFIG["aliases"][key]])
 		return items
 	def check(self, 
 		# the alias to check.
@@ -98,6 +112,7 @@ class Aliases(object):
 
 		# create non existant.
 		elif not exists and create:
+			print("1; info username:",info['username'])
 			username,public_ip,private_ip,public_port,private_port,private_key,public_key,passphrase,smartcard,pin,save,checks = Dictionary(info).unpack({
 				"username":None, 
 				"public_ip":None,
@@ -111,6 +126,7 @@ class Aliases(object):
 				"pin":None,
 				"save":True,
 				"checks":True, })
+			print("2; username:",username)
 			return self.create(
 				alias=alias,
 				# the users.
@@ -311,33 +327,36 @@ class Aliases(object):
 				"pin":None,
 				"alias":None,
 			})
+			print("3; username:",username)
 		
 		# check specific.
 		if self.specific:
 			if alias == None: alias = self.alias
 
 		# checks.
-		response = r3sponse.check_parameters({
-			"alias":alias,
-			"username":username,
-			"public_ip":public_ip,
-			"private_ip":private_ip,
-			"public_port":public_port,
-			"private_port":private_port,
-			"private_key":private_key,
-			"public_key":public_key,
-			#"smartcard:bool":smartcard,
-		}, empty_value=None)
+		response = r3sponse.check_parameters(
+			traceback=self.__traceback__(function="create"),
+			parameters={
+				"alias":alias,
+				"username":username,
+				"public_ip":public_ip,
+				"private_ip":private_ip,
+				"public_port":public_port,
+				"private_port":private_port,
+				"private_key":private_key,
+				"public_key":public_key,
+				#"smartcard:bool":smartcard,
+			})
 		if not response["success"]: return response
 		if smartcard:
 			response = r3sponse.check_parameters({
 				"pin":pin,
-			}, empty_value=None)
+			}, empty_value=None, traceback=self.__traceback__(function="create"))
 			if not response["success"]: return response
 		else:
 			response = r3sponse.check_parameters({
 				"passphrase":passphrase,
-			}, empty_value=None)
+			}, empty_value=None, traceback=self.__traceback__(function="create"))
 			if not response["success"]: return response
 
 		# check encryption activated.
@@ -359,7 +378,7 @@ class Aliases(object):
 
 		# info.
 		json_config, config = {}, ""
-		if NETWORK_INFO["public_ip"] == public_ip and netw0rk.network.ping(private_ip, timeout=0.5).up == True:
+		if not self.public(public_ip=public_ip, private_ip=private_ip):
 			ip = private_ip
 			port = private_port
 		else:
@@ -414,8 +433,9 @@ class Aliases(object):
 			"json":json_config,
 			"str":config,
 		})
-	def sync(self, aliases=["*"], interactive=None):
+	def sync(self, aliases=["*"], interactive=None, log_level=None):
 		if interactive == None: interactive = INTERACTIVE
+		if log_level == None: log_level = self.log_level
 
 		# all aliases.
 		if "*" in aliases or "all" in aliases:
@@ -424,7 +444,11 @@ class Aliases(object):
 			else:
 				aliases = list(CONFIG["aliases"].keys())
 		_aliases_ = list(aliases)
-			
+		
+		# loader.
+		if log_level >= 0:
+			loader = syst3m.console.Loader(f"Synchronizing {len(_aliases_)} aliases.")
+
 		# check ssh dir.
 		if not Files.exists(f"{syst3m.defaults.vars.home}/.ssh"): os.system(f"mkdir {syst3m.defaults.vars.home}/.ssh && chown -R {syst3m.defaults.vars.user}:{syst3m.defaults.vars.group} {syst3m.defaults.vars.home}/.ssh && chmod 700 {syst3m.defaults.vars.home}/.ssh")
 		
@@ -461,7 +485,9 @@ class Aliases(object):
 				
 				# check existance.
 				response = self.check(alias=alias)
-				if not response.success: return response
+				if not response.success: 
+					if log_level >= 0: loader.stop(success=False)
+					return response
 
 				# proceed.
 				checked = Dictionary(path=False, dictionary=info).check(default={
@@ -496,10 +522,14 @@ class Aliases(object):
 						else:
 							# check encryption activated.
 							if not encryption.activated:
+								
+								if log_level >= 0: loader.stop(success=False)
 								return r3sponse.error("The encryption requires to be activated.")
 							new_passphrase = False
 							response = encryption.encryption.decrypt(checked["pin"])
-							if not response.success: return response
+							if not response.success: 
+								if log_level >= 0: loader.stop(success=False)
+								return response
 							passphrase = response.decrypted.decode()
 					else:	
 						if checked["passphrase"] in [False, None, "", "none", "None"]:
@@ -510,10 +540,14 @@ class Aliases(object):
 						else:
 							# check encryption activated.
 							if not encryption.activated:
+								
+								if log_level >= 0: loader.stop(success=False)
 								return r3sponse.error("The encryption requires to be activated.")
 							new_passphrase = False
 							response = encryption.encryption.decrypt(checked["passphrase"])
-							if not response.success: return response
+							if not response.success: 
+								if log_level >= 0: loader.stop(success=False)
+								return response
 							passphrase = response.decrypted.decode()
 					if has_passphrase:
 						if checked["smartcard"] == True:
@@ -521,27 +555,39 @@ class Aliases(object):
 						else:
 							response = agent.check(public_key=checked["public_key"], raw=False)
 						if not response["success"]:
-							if "is not added" not in response["error"]: return response
+							if "is not added" not in response["error"]: 
+								if log_level >= 0: loader.stop(success=False)
+								return response
 							elif "is not added" in response["error"]:
 								if checked["smartcard"]:
 									response = agent.add(private_key=checked["private_key"], smartcard=True, pin=passphrase)
-									if not response["success"]: return response
+									if not response["success"]: 
+										if log_level >= 0: loader.stop(success=False)
+										return response
 								else:
 									response = agent.add(private_key=checked["private_key"], passphrase=passphrase)
-									if not response["success"]: return response
+									if not response["success"]: 
+										if log_level >= 0: loader.stop(success=False)
+										return response
 						if new_passphrase:
 							# check encryption activated.
 							if not encryption.activated:
+								
+								if log_level >= 0: loader.stop(success=False)
 								return r3sponse.error("The encryption requires to be activated.")
 							response = encryption.encryption.encrypt(passphrase)
-							if not response.success: return response
+							if not response.success: 
+								if log_level >= 0: loader.stop(success=False)
+								return response
 							if checked["smartcard"] == True:
 								CONFIG["aliases"][alias]["pin"] = response.encrypted.decode()
 							else:
 								CONFIG["aliases"][alias]["passphrase"] = response.encrypted.decode()
 							utils.save_config_safely()
 				response = self.create(save=False, checks=False, serialized=Dictionary(dictionary=checked).append({"alias":alias}))
-				if not response["success"]: return response
+				if not response["success"]: 
+					if log_level >= 0: loader.stop(success=False)
+					return response
 				aliases += response["str"]
 				c += 1
 
@@ -549,7 +595,10 @@ class Aliases(object):
 		Files.save(f"{syst3m.defaults.vars.home}/.ssht00ls/lib/aliases", aliases)
 
 		# handler.
+		if log_level >= 0: loader.stop()
 		return r3sponse.success(f"Successfully synchronized {c} alias(es).")
+	def public(self, public_ip=None, private_ip=None):
+		return not (NETWORK_INFO["public_ip"] == public_ip and netw0rk.network.ping(private_ip, timeout=0.5).up == True)
 
 # initialized objects.
 aliases = Aliases()
