@@ -108,9 +108,10 @@ if CHECKS and not RESET_CACHE:
 		r3sponse.log(f"private ip: {NETWORK_INFO['private_ip']}")
 
 	# check lib.
-	if not Files.exists(f"{SOURCE_PATH}/lib"):
+	if not Files.exists(f"{SOURCE_PATH}/lib") or cl1.argument_present("--download-lib"):
 		r3sponse.log("Downloading the ssht00ls library.")
-		os.system(f"rm -fr /tmp/ssht00ls && git clone https://github.com/vandenberghinc/ssht00ls /tmp/ssht00ls && rsync -azq /tmp/ssht00ls/ssht00ls/lib/ {SOURCE_PATH}/lib/")
+		os.system(f"rm -fr /tmp/ssht00ls && git clone https://github.com/vandenberghinc/ssht00ls /tmp/ssht00ls && rsync -azq /tmp/ssht00ls/ssht00ls/lib/ {Files.join(SOURCE_PATH, 'lib/')}")
+		if cl1.argument_present("--download-lib"): sys.exit(0)
 
 	# check usr lib.
 	if not Files.exists("/usr/local/lib/ssht00ls"):
@@ -172,7 +173,7 @@ if CHECKS and not RESET_CACHE:
 				r3sponse.log(response=response, json=syst3m.defaults.options.json)
 				sys.exit(1)
 		elif cl1.argument_present("--start-agent"):
-			if not webserver.running(): 
+			if not webserver.running: 
 				if syst3m.defaults.options.log_level >= 1:
 					r3sponse.log(f"{ALIAS}: starting the ssht00ls agent.")
 				webserver.start()
@@ -180,7 +181,7 @@ if CHECKS and not RESET_CACHE:
 			else:
 				r3sponse.log(error=f"The {webserver.id} is already running.", json=syst3m.defaults.options.json)
 				sys.exit(1)
-		elif INTERACTIVE and not webserver.running(): 
+		elif INTERACTIVE and not webserver.running: 
 			if syst3m.defaults.options.log_level >= 1:
 				r3sponse.log(f"{ALIAS}: forking the ssht00ls agent.")
 			response = webserver.fork()
