@@ -6,9 +6,13 @@ from ssht00ls.classes.config import *
 from ssht00ls.classes import utils
 
 # the ssh connections object class.
-class Connections(object):
+class Connections(syst3m.objects.Traceback):
 	def __init__(self):
-		a=1
+		
+		# defaults.
+		syst3m.objects.Traceback.__init__(self, traceback="ssht00ls.connections", raw_traceback="ssht00ls.classes.connections.Connections")
+
+		#
 	def list(self, filter="ssh"):
 		output = syst3m.utils.__execute_script__("""ss | grep ssh | awk '{print $1","$2","$3","$4","$5","$6}' """)
 		connections = {}
