@@ -6,9 +6,14 @@ from ssht00ls.classes.config import *
 from ssht00ls.classes import utils
 
 # the installation object class.
-class Installation(object):
-	def __init__(self):
-		a=1
+class Installation(syst3m.objects.Traceback):
+	def __init__(self,
+	):
+		
+		# defaults.
+		syst3m.objects.Traceback.__init__(self, traceback="ssht00ls.installation", raw_traceback="ssht00ls.classes.installation.Installation")
+
+		#
 	def install(self, 
 		# optional define the user (leave None for current user).
 		username=None,
