@@ -7,11 +7,12 @@ from ssht00ls.classes import utils
 from ssht00ls.classes.smartcards import smartcards
 
 # the scp object class.
-class SCP(object):
-	def __init__(self):
+class SCP(syst3m.objects.Traceback):
+	def __init__(self,
+	):
 
-		# variables.
-		a = 1
+		# defaults.
+		syst3m.objects.Traceback.__init__(self, traceback="ssht00ls.scp", raw_traceback="ssht00ls.classes.scp.SCP")
 
 		#
 	def download(self, 
@@ -38,14 +39,14 @@ class SCP(object):
 				"client_path":client_path,
 				"key_path":key_path,
 				"port":port,
-			})
+			}, traceback=self.__traceback__(function="download"))
 			if not response["success"]: return response
 		else:
 			response = r3sponse.check_parameters(empty_value=None, parameters={
 				"alias":alias,
 				"server_path":server_path,
 				"client_path":client_path,
-			})
+			}, traceback=self.__traceback__(function="download"))
 			if not response["success"]: return response
 
 		# check client path.
@@ -103,14 +104,14 @@ class SCP(object):
 				"client_path":client_path,
 				"key_path":key_path,
 				"port":port,
-			})
+			}, traceback=self.__traceback__(function="upload"))
 			if not response["success"]: return response
 		else:
 			response = r3sponse.check_parameters(empty_value=None, parameters={
 				"alias":alias,
 				"server_path":server_path,
 				"client_path":client_path,
-			})
+			}, traceback=self.__traceback__(function="upload"))
 			if not response["success"]: return response
 
 		# check client path.
