@@ -11,9 +11,13 @@ def __check_os__(supported=[]):
 	return r3sponse.success(f"Supported operating system [{syst3m.defaults.vars.os}].")
 
 # the manager class.
-class SmartCards(object):
-	def __init__(self):	
+class SmartCards(syst3m.objects.Traceback):
+	def __init__(self, 
+	):	
 		
+		# defaults.
+		syst3m.objects.Traceback.__init__(self, traceback="ssht00ls.smartcards", raw_traceback="ssht00ls.classes.smartcards.SmartCards")
+
 		# key path.
 		if syst3m.defaults.vars.os in ["linux"]: 
 			self.path = None
@@ -95,7 +99,7 @@ class SmartCards(object):
 		})
 
 # the smart card class.
-class SmartCard(object):
+class SmartCard(syst3m.objects.Traceback):
 	# the smart card is by default a YubiKey 5 NFC
 	# main docs: https://support.yubico.com/support/solutions/articles/15000012643-yubikey-manager-cli-ykman-user-manual#ykman_piv_change-management-key1suvy
 	# piv: https://developers.yubico.com/PIV/Guides/SSH_with_PIV_and_PKCS11.html
@@ -104,6 +108,9 @@ class SmartCard(object):
 	# another ssh : https://somm15.github.io/yubikey/macos/ssh/2018/11/20/welcome-to-jekyll.html
 	def __init__(self, serial_number=None):	
 
+		# defaults.
+		syst3m.objects.Traceback.__init__(self, traceback="ssht00ls.SmartCard", raw_traceback="ssht00ls.classes.smartcards.SmartCard")	
+
 		# arguments.
 		self.serial_number = serial_number
 
@@ -156,6 +163,7 @@ class SmartCard(object):
 		# check params.
 		response = r3sponse.check_parameters(
 			empty_value=None,
+			traceback=self.__traceback__(function="unblock_pin"),
 			parameters={
 				"pin":pin,
 				"puk":puk,
@@ -187,6 +195,7 @@ class SmartCard(object):
 		# check params.
 		response = r3sponse.check_parameters(
 			empty_value=None,
+			traceback=self.__traceback__(function="change_pin"),
 			parameters={
 				"new":new,
 				"old":old,
@@ -220,6 +229,7 @@ class SmartCard(object):
 		# check params.
 		response = r3sponse.check_parameters(
 			empty_value=None,
+			traceback=self.__traceback__(function="change_puk"),
 			parameters={
 				"new":new,
 				"old":old,
@@ -252,6 +262,7 @@ class SmartCard(object):
 		# check params.
 		response = r3sponse.check_parameters(
 			empty_value=None,
+			traceback=self.__traceback__(function="generate_key"),
 			parameters={
 				"pin":pin,
 			})
@@ -289,6 +300,7 @@ class SmartCard(object):
 		# check params.
 		response = r3sponse.check_parameters(
 			empty_value=None,
+			traceback=self.__traceback__(function="generate_management_key"),
 			parameters={
 				"pin":pin,
 			})
