@@ -15,31 +15,6 @@ def save_config_safely():
 		loader.stop()
 		raise KeyboardInterrupt(e)
 
-# set a file path permission.
-def __set_file_path_permission__(path, permission=755, sudo=False, recursive=False):
-	if recursive: recursive = "-R "
-	else: recursive = ""
-	if sudo: sudo = "sudo "
-	else: sudo = ""
-	os.system(f"{sudo}chmod {recursive}{permission} {path}")
-# set a file path ownership.
-def __set_file_path_ownership__(path, owner=os.environ.get("USER"), group=None, sudo=False, recursive=False):
-	if recursive: recursive = "-R "
-	else: recursive = ""
-	if sudo: sudo = "sudo "
-	else: sudo = ""
-	if group == None: group = __get_empty_group__()
-	os.system(f"{sudo}chown {recursive}{owner}:{group} {path}")
-def __delete_file_path__(path, sudo=False, forced=False):
-	if sudo: sudo = "sudo "
-	else: sudo = ""
-	options = ""
-	if forced: 
-		options = " -f "
-		if os.path.isdir(path): options = " -fr "
-	elif os.path.isdir(path): options = " -r "
-	os.system(f"{sudo}rm{options}{path}")
-
 # converting variables.
 def __array_to_string__(array, joiner=" "):
 	string = ""
@@ -139,8 +114,9 @@ def __execute_script__(
 	input=None,
 ):
 	path = f"/tmp/shell_script.{__generate_pincode__(characters=32)}.sh"
-	__save_bytes__(path, script.encode())
-	__set_file_path_permission__(path,permission=755)
+	with open(str(path), "wb") as file:
+		file.write(str(data))
+	os.system(f"chmod +x {path}")
 	output = __execute__(
 		command=[f"sh", f"{path}"],
 		wait=wait,
@@ -148,39 +124,5 @@ def __execute_script__(
 		return_format=return_format, 
 		shell=shell,
 		input=input,)
-	__delete_file_path__(path, forced=True)
+	os.system(f"rm -fr {path}")
 	return output
-
-# save & load jsons.
-def __load_json__(path):
-	data = None
-	with open(path, "r") as json_file:
-		data = json.load(json_file)
-	return data
-def __save_json__(path, data):
-	with open(path, "w") as json_file:
-		json.dump(data, json_file, indent=4, ensure_ascii=False)
-
-# save & load files.
-def __load_file__(path):
-	file = open(path,mode='rb')
-	data = file.read().decode()
-	file.close()
-	return data
-def __save_file__(path, data):
-	file = open(path, "w+") 
-	file.write(data)
-	file.close()
-
-
-# save & load bytes.
-def __load_bytes__(path):
-	data = None
-	with open(path, "rb") as file:
-		data = file.read()
-	return data
-def __save_bytes__(path, data):
-	with open(path, "wb") as file:
-		file.write(data)
-
-
